##  Adding the SAP LeanIX App in Microsoft Teams
SAP LeanIX App can be added to your Microsoft Teams from the Apps section in Microsoft Teams. To add the SAP LeanIX App in Microsoft Teams:
  1. Go to Apps in your Microsoft Teams.
  2. In the search bar, search for SAP LeanIX.
  3. Click Add.


**Tip**
You can also directly download the SAP LeanIX App through this link: [Microsoft AppSource.![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fappsource.microsoft.com%2Fen-us%2Fproduct%2Foffice%2FWA200006527%3Ftab%3DOverview "https://appsource.microsoft.com/en-us/product/office/WA200006527?tab=Overview")
![Adding SAP LeanIX App to Microsoft Teams](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274aab397a44101486d9e86942e11a62_LowRes.png)
Adding SAP LeanIX App to Microsoft Teams
